SliceSink

Struct SliceSink 

pub struct SliceSink<'a> { /* private fields */ }
SliceSink writes into a preallocated &mut [u8].

Handling of Capacity

Extend methods will panic if there’s insufficient capacity left in the Sink.

Invariants

  • Bytes [..pos()] are always initialized.

Implementations

Source

impl<'a> SliceSink<'a>

pub fn new(output: &'a mut [u8], pos: usize) -> Self

Creates a Sink backed by the given byte slice. pos defines the initial output position in the Sink.

Panics

Panics if pos is out of bounds.